==> react-rich-diff-0.2.0.tgz: package/lib/schema/index.js <==
'use strict';

var _nodes, _marks;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint-disable react/prop-types */
var React = require('react');

var _require = require('markup-it'),
    BLOCKS = _require.BLOCKS,
    MARKS = _require.MARKS,
    INLINES = _require.INLINES;

var Heading = require('./Heading');
var Image = require('./Image');
var Link = require('./Link');

function componentFromtag(tagName) {
    return function (props) {
        return React.createElement(tagName, _extends({}, props.attributes), props.children);
    };
}

var SCHEMA = {
    defaultBlock: componentFromtag('div'),
    defaultInline: componentFromtag('span'),
    // Nodes
    nodes: (_nodes = {}, _defineProperty(_nodes, BLOCKS.PARAGRAPH, componentFromtag('p')), _defineProperty(_nodes, BLOCKS.BLOCKQUOTE, componentFromtag('blockquote')), _defineProperty(_nodes, BLOCKS.HR, function (props) {
        return React.createElement('hr', props.attributes);
    }), _defineProperty(_nodes, BLOCKS.CODE, componentFromtag('pre')), _defineProperty(_nodes, BLOCKS.TABLE, componentFromtag('table')), _defineProperty(_nodes, BLOCKS.TABLE_ROW, componentFromtag('tr')), _defineProperty(_nodes, BLOCKS.TABLE_CELL, componentFromtag('td')), _defineProperty(_nodes, BLOCKS.UL_LIST, componentFromtag('ul')), _defineProperty(_nodes, BLOCKS.OL_LIST, componentFromtag('ol')), _defineProperty(_nodes, BLOCKS.LIST_ITEM, componentFromtag('li')), _defineProperty(_nodes, BLOCKS.HEADING_1, Heading), _defineProperty(_nodes, BLOCKS.HEADING_2, Heading), _defineProperty(_nodes, BLOCKS.HEADING_3, Heading), _defineProperty(_nodes, BLOCKS.HEADING_4, Heading), _defineProperty(_nodes, BLOCKS.HEADING_5, Heading), _defineProperty(_nodes, BLOCKS.HEADING_6, Heading), _defineProperty(_nodes, INLINES.IMAGE, Image), _defineProperty(_nodes, INLINES.LINK, Link), _nodes),
    marks: (_marks = {}, _defineProperty(_marks, MARKS.BOLD, function (props) {
        return React.createElement(
            'strong',
            null,
            props.children
        );
    }), _defineProperty(_marks, MARKS.ITALIC, function (props) {
        return React.createElement(
            'em',
            null,
            props.children
        );
    }), _defineProperty(_marks, MARKS.STRIKETHROUGH, function (props) {
        return React.createElement(
            'del',
            null,
            props.children
        );
    }), _defineProperty(_marks, MARKS.CODE, function (props) {
        return React.createElement(
            'code',
            null,
            props.children
        );
    }), _marks)
};

module.exports = SCHEMA;

==> react-rich-diff-0.3.0.tgz: package/lib/schema/index.js <==
'use strict';

var _nodes, _marks;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint-disable react/prop-types */
var React = require('react');

var _require = require('markup-it'),
    BLOCKS = _require.BLOCKS,
    MARKS = _require.MARKS,
    INLINES = _require.INLINES;

var Heading = require('./Heading');
var Image = require('./Image');
var Link = require('./Link');
var Table = require('./Table');

function componentFromtag(tagName) {
    return function (props) {
        return React.createElement(tagName, _extends({}, props.attributes), props.children);
    };
}

var SCHEMA = {
    defaultBlock: componentFromtag('div'),
    defaultInline: componentFromtag('span'),
    // Nodes
    nodes: (_nodes = {}, _defineProperty(_nodes, BLOCKS.PARAGRAPH, componentFromtag('p')), _defineProperty(_nodes, BLOCKS.BLOCKQUOTE, componentFromtag('blockquote')), _defineProperty(_nodes, BLOCKS.HR, function (props) {
        return React.createElement('hr', props.attributes);
    }), _defineProperty(_nodes, BLOCKS.CODE, componentFromtag('pre')), _defineProperty(_nodes, BLOCKS.TABLE, Table), _defineProperty(_nodes, BLOCKS.TABLE_ROW, componentFromtag('tr')), _defineProperty(_nodes, BLOCKS.TABLE_CELL, componentFromtag('td')), _defineProperty(_nodes, BLOCKS.UL_LIST, componentFromtag('ul')), _defineProperty(_nodes, BLOCKS.OL_LIST, componentFromtag('ol')), _defineProperty(_nodes, BLOCKS.LIST_ITEM, componentFromtag('li')), _defineProperty(_nodes, BLOCKS.HEADING_1, Heading), _defineProperty(_nodes, BLOCKS.HEADING_2, Heading), _defineProperty(_nodes, BLOCKS.HEADING_3, Heading), _defineProperty(_nodes, BLOCKS.HEADING_4, Heading), _defineProperty(_nodes, BLOCKS.HEADING_5, Heading), _defineProperty(_nodes, BLOCKS.HEADING_6, Heading), _defineProperty(_nodes, INLINES.IMAGE, Image), _defineProperty(_nodes, INLINES.LINK, Link), _nodes),
    marks: (_marks = {}, _defineProperty(_marks, MARKS.BOLD, function (props) {
        return React.createElement(
            'strong',
            null,
            props.children
        );
    }), _defineProperty(_marks, MARKS.ITALIC, function (props) {
        return React.createElement(
            'em',
            null,
            props.children
        );
    }), _defineProperty(_marks, MARKS.STRIKETHROUGH, function (props) {
        return React.createElement(
            'del',
            null,
            props.children
        );
    }), _defineProperty(_marks, MARKS.CODE, function (props) {
        return React.createElement(
            'code',
            null,
            props.children
        );
    }), _marks)
};

module.exports = SCHEMA;
